<?php
/*
Plugin Name: eBay Store
Plugin URI: http://esoftie.com/products/free-ebay-wordpress-plugin/
Description: This plug-in displays your eBay stores on WordPress pages or posts. Go to <strong><a href="/wp-admin/options-general.php?page=ebay-store">Settings > eBay Store</a></strong> to generate your store snippet. Remember to <strong><a href="http://esoftie.com/products/free-ebay-wordpress-plugin/" target="_blank">Check for Updates</a></strong> from time to time.
Author: eSoftie LLC
Version: 1.2
Author URI: http://esoftie.com
*/

class eBayStoreTag
{
	static $version = '1.2';
	
	static function init()
	{
		add_action('admin_menu', array('eBayStoreTag', 'CreateAdminMenu'));
		add_shortcode('ebaystore', array('eBayStoreTag', 'ShowStore'));
		add_filter('plugin_action_links', array('eBayStoreTag', 'CreateSettingsPluginLink'), 10, 2);
	}
	
	/* Generate an action link in Plugins page */
	static function CreateSettingsPluginLink($_links, $file)
	{
		if(strlen($file) > strlen(__FILE__)) return $_links;
		
		if($file == substr(__FILE__, strlen(__FILE__) - strlen($file)))
		{
			$settings_link = '<a href="/wp-admin/options-general.php?page=ebay-store">Settings</a>';
			
			array_unshift($_links, $settings_link );
		}
		
		return $_links;
	}
	
	static function CreateAdminMenu()
	{
		add_options_page('eBay Store Settings', 'eBay Store', 'manage_options', 'ebay-store', array('eBayStoreTag', 'SettingsForm'));
	}
	
	/* Replaces tags with HTML content, and returns the HTML content */
	static function ShowStore($_atts, $content = '')
	{
		$_atts = shortcode_atts(array(
				'hide-duplicates' => 0,
				'country_id' => 0,
				'combine_accounts' => 0,
				'items_per_page' => 24
				), $_atts, 'ebaystore');
		
		$seller_ids = $content;
		
		return '<script type="text/javascript" src="https://esoftie.com/apps/ebaywidget/js.php?seller_id='.$content.'&country_id='.$_atts['country_id'].'&sort_by=BestMatch&combine_accounts='.$_atts['combine_accounts'].'&items_per_page='.$_atts['items_per_page'].'"></script>';
	}
	
	static function SettingsForm()
	{
?>

<style>
#ThemeSettings table th
{
	text-align:left;
	vertical-align:top;
	padding-top:4px;
}
</style>

<div id="ThemeSettings" class="wrap">
	<div id="icon-edit-pages" class="icon32 icon32-posts-page"><br /></div>
	<h2>eBay Store v<?php echo eBayStoreTag::$version; ?> - Tag Generator</h2>
	
	<form id="TagGenerator">
	
	<table cellspacing="10">
		<tr>
			<th>eBay User IDs:</th>
			<td>
				<input type="text" name="seller_ids" size="60" /> <span style="color:#F00;">(required)</span>
			</td>
		</tr>
		<tr>
			<th>Country:</th>
			<td>
				<select name="country_id"> <option value="0">United States</option> <option value="2">Canada</option> <option value="210">Canada (French)</option> <option value="3">United Kingdom</option> <option value="15">Australia</option> <option value="16">Austria</option> <option value="123">Belgium (Dutch)</option> <option value="23">Belgium (French)</option> <option value="71">France</option> <option value="77">Germany</option> <option value="101">Italy</option> <option value="146">Netherlands</option> <option value="186">Spain</option> <option value="193">Switzerland</option> <option value="201">Hong Kong</option> <option value="216">Singapore</option> <option value="203">India</option> <option value="205">Ireland</option> <option value="207">Malaysia</option> <option value="211">Philippines</option> <option value="212">Poland</option> <option value="218">Sweden</option> </select>
			</td>
		</tr>
		<tr>
			<th>Order By:</th>
			<td>
				<select name="sort_by"> <option value="BestMatch">Best Match</option> <option value="PricePlusShippingLowest">Price + Shipping (low to high)</option> <option value="PricePlusShippingHighest">Price + Shipping (hi to low)</option> <option value="EndTimeSoonest">Ending Time (sooner first)</option> <option value="StartTimeNewest">Start Time (newer first)</option> </select>
			</td>
		</tr>
		<tr>
			<th>Items per Page:</th>
			<td>
				<select name="items_per_page" style="width:70px;"> <option value="12">12</option> <option value="16">16</option> <option value="18">18</option> <option value="20">20</option> <option selected="selected" value="24">24</option> <option value="25">25</option> <option value="30">30</option> <option value="50">50</option> </select>
			</td>
		</tr>
		<tr>
			<th></th>
			<td>
				<label><input name="combine_accounts" type="checkbox" value="1" /> Combine items from multiple eBay accounts into one list.</label>
			</td>
		</tr>
		<tr>
			<th></th>
			<td style="padding-top:15px;">
				<input type="button" class="button-primary" value="Generate Tag" onclick="GenerateStoreTag()">
			</td>
		</tr>
	</table>
	
	</form>
	
	<br />
	<div id="TagResults" style="display:none;">
		<h2>Generated Tag</h2>
		<span style="color:#999;">Copy this tag into your page or a post where you want your store to appear:</span>
		<br />
		<textarea id="GeneratedTag" style="width:600px; height:100px; padding:10px; color:#0A0;" onclick="this.select();" onfocus="this.select()"></textarea>
	</div>
</div>

<script type="text/javascript">
function getInputValue(n)
{
	var f = document.getElementById('TagGenerator');
	
	if(f[n].type == 'checkbox')
	{
		if(f[n].checked)
		{
			return f[n].value;
		}
		else
		{
			return null;
		}
	}
	else
	{
		return f[n].value;
	}
}

function GenerateStoreTag()
{
	if(getInputValue('seller_ids') == '')
	{
		alert('Please enter your eBay User ID, then try again.');
		return;
	}
	
	var str = '[ebaystore items_per_page=' + getInputValue('items_per_page') + ' combine_accounts=' + (getInputValue('combine_accounts') == null ? '0' : getInputValue('combine_accounts')) + ' country_id=' + getInputValue('country_id') + ']' + getInputValue('seller_ids') + '[/ebaystore]';
	document.getElementById('GeneratedTag').value = str;
	
	document.getElementById('TagResults').style.display = '';
}
</script>
<?php
	}
}

eBayStoreTag::init();
?>
